summaryrefslogtreecommitdiffstats
path: root/kviewshell
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:17:19 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:17:19 -0600
commit00b4f54142276b0e2272ca56e48558551ab7b2b0 (patch)
tree1d1054b59fc2e76d0c2bae00126bdf65d9318865 /kviewshell
parentc7549e238d15850306158ae153fc99126c84ab9d (diff)
downloadtdegraphics-00b4f54142276b0e2272ca56e48558551ab7b2b0.tar.gz
tdegraphics-00b4f54142276b0e2272ca56e48558551ab7b2b0.zip
Rename a number of libraries and executables to avoid conflicts with KDE4
Diffstat (limited to 'kviewshell')
-rw-r--r--kviewshell/CMakeLists.txt20
-rw-r--r--kviewshell/Makefile.am22
-rw-r--r--kviewshell/TODO6
-rw-r--r--kviewshell/empty_multipage.h4
-rw-r--r--kviewshell/kprintDialogPage_pageoptions.cpp4
-rw-r--r--kviewshell/kviewpart.cpp8
-rw-r--r--kviewshell/kviewpart.h4
-rw-r--r--kviewshell/kviewpart_iface.h2
-rw-r--r--kviewshell/kviewshell.cpp2
-rw-r--r--kviewshell/kviewshell.h2
-rw-r--r--kviewshell/main.cpp4
-rw-r--r--kviewshell/plugins/djvu/CMakeLists.txt2
-rw-r--r--kviewshell/plugins/djvu/Makefile.am2
-rw-r--r--kviewshell/plugins/djvu/djvumultipage.cpp6
-rw-r--r--kviewshell/plugins/djvu/djvumultipage.h6
-rw-r--r--kviewshell/plugins/djvu/kprintDialogPage_DJVUpageoptions.cpp4
-rw-r--r--kviewshell/tdemultipage.cpp (renamed from kviewshell/kmultipage.cpp)12
-rw-r--r--kviewshell/tdemultipage.desktop (renamed from kviewshell/kmultipage.desktop)0
-rw-r--r--kviewshell/tdemultipage.h (renamed from kviewshell/kmultipage.h)22
-rw-r--r--kviewshell/tdemultipageInterface.h (renamed from kviewshell/kmultipageInterface.h)6
20 files changed, 69 insertions, 69 deletions
diff --git a/kviewshell/CMakeLists.txt b/kviewshell/CMakeLists.txt
index 8a9de930..3ad83e46 100644
--- a/kviewshell/CMakeLists.txt
+++ b/kviewshell/CMakeLists.txt
@@ -30,13 +30,13 @@ link_directories(
##### headers ###################################
install( FILES
- kmultipageInterface.h
+ tdemultipageInterface.h
DESTINATION ${INCLUDE_INSTALL_DIR} )
install( FILES
anchor.h bookmark.h pageView.h documentPageCache.h
documentRenderer.h documentWidget.h history.h hyperlink.h
- kmultipage.h length.h pageNumber.h pageSize.h renderedDocumentPage.h
+ tdemultipage.h length.h pageNumber.h pageSize.h renderedDocumentPage.h
renderedDocumentPagePixmap.h renderedDocumentPagePrinter.h
selection.h simplePageSize.h textBox.h zoom.h zoomlimits.h
DESTINATION ${INCLUDE_INSTALL_DIR}/kviewshell )
@@ -46,7 +46,7 @@ install( FILES
install( FILES kviewshell.rc DESTINATION ${DATA_INSTALL_DIR}/kviewshell )
install( FILES kviewerpart.rc DESTINATION ${DATA_INSTALL_DIR}/kviewerpart )
-install( FILES kmultipage.desktop DESTINATION ${SERVICETYPES_INSTALL_DIR} )
+install( FILES tdemultipage.desktop DESTINATION ${SERVICETYPES_INSTALL_DIR} )
install( FILES emptymultipage.desktop DESTINATION ${SERVICES_INSTALL_DIR} )
install( FILES kviewshell.kcfg DESTINATION ${KCFG_INSTALL_DIR} )
@@ -67,18 +67,18 @@ tde_add_library( kviewshell STATIC_PIC AUTOMOC
)
-##### kmultipage (shared) #######################
+##### tdemultipage (shared) #######################
-tde_add_library( kmultipage SHARED AUTOMOC
+tde_add_library( tdemultipage SHARED AUTOMOC
SOURCES
- kmultipage.cpp pageView.cpp marklist.cpp kmultipageInterface.skel
+ tdemultipage.cpp pageView.cpp marklist.cpp tdemultipageInterface.skel
units.cpp pageSize.cpp simplePageSize.cpp renderedDocumentPage.cpp
renderedDocumentPagePixmap.cpp renderedDocumentPagePrinter.cpp
documentPageCache.cpp documentWidget.cpp searchWidget.cpp
selection.cpp documentRenderer.cpp history.cpp kvsprefs.kcfgc
tableOfContents.cpp kprintDialogPage_pageoptions.cpp
VERSION 0.0.0
- LINK kparts-shared tdeprint-shared
+ LINK tdeparts-shared tdeprint-shared
DESTINATION ${LIB_INSTALL_DIR}
)
@@ -91,7 +91,7 @@ tde_add_kpart( kviewerpart AUTOMOC
pageSizeDialog.cpp pageSize.cpp sizePreview.cpp zoom.cpp
units.cpp kvsprefs.kcfgc optionDialogGUIWidget_base.ui
optionDialogAccessibilityWidget.ui simplePageSize.cpp
- LINK ifaces-static kparts-shared
+ LINK ifaces-static tdeparts-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
@@ -101,7 +101,7 @@ tde_add_kpart( kviewerpart AUTOMOC
tde_add_executable( kviewshell AUTOMOC
SOURCES
main.cpp
- LINK kviewshell-static kparts-shared
+ LINK kviewshell-static tdeparts-shared
DESTINATION ${BIN_INSTALL_DIR}
)
@@ -111,7 +111,7 @@ tde_add_executable( kviewshell AUTOMOC
tde_add_kpart( emptymultipagepart AUTOMOC
SOURCES
empty_multipage.cpp emptyRenderer.cpp
- LINK kmultipage-shared
+ LINK tdemultipage-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/kviewshell/Makefile.am b/kviewshell/Makefile.am
index 5be569e4..a9691440 100644
--- a/kviewshell/Makefile.am
+++ b/kviewshell/Makefile.am
@@ -1,12 +1,12 @@
SUBDIRS = . pics plugins
INCLUDES= $(all_includes)
-include_HEADERS = kmultipageInterface.h
+include_HEADERS = tdemultipageInterface.h
####### Files
bin_PROGRAMS = kviewshell
-lib_LTLIBRARIES = libkmultipage.la
+lib_LTLIBRARIES = libtdemultipage.la
kde_module_LTLIBRARIES = kviewerpart.la emptymultipagepart.la
noinst_LTLIBRARIES = libifaces.la libkviewshell.la
@@ -18,9 +18,9 @@ kviewerpart_la_SOURCES = kviewpart.cpp pageSizeWidget_base.ui \
optionDialogGUIWidget_base.ui optionDialogAccessibilityWidget.ui simplePageSize.cpp
kviewerpart_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN) -module
-kviewerpart_la_LIBADD = ./libifaces.la $(LIB_KFILE) -lkparts
+kviewerpart_la_LIBADD = ./libifaces.la $(LIB_KFILE) -ltdeparts
-libkmultipage_la_SOURCES = kmultipage.cpp pageView.cpp marklist.cpp kmultipageInterface.skel \
+libtdemultipage_la_SOURCES = tdemultipage.cpp pageView.cpp marklist.cpp tdemultipageInterface.skel \
units.cpp pageSize.cpp simplePageSize.cpp renderedDocumentPage.cpp renderedDocumentPagePixmap.cpp \
renderedDocumentPagePrinter.cpp documentPageCache.cpp documentWidget.cpp searchWidget.cpp \
selection.cpp documentRenderer.cpp history.cpp kvsprefs.kcfgc tableOfContents.cpp \
@@ -29,21 +29,21 @@ libkmultipage_la_SOURCES = kmultipage.cpp pageView.cpp marklist.cpp kmultipageIn
kde_kcfg_DATA = kviewshell.kcfg
-libkmultipage_la_LDFLAGS = $(all_libraries)
-libkmultipage_la_LIBADD = $(LIB_KFILE) -ltdeprint -lkparts
+libtdemultipage_la_LDFLAGS = $(all_libraries)
+libtdemultipage_la_LIBADD = $(LIB_KFILE) -ltdeprint -ltdeparts
emptymultipagepart_la_SOURCES = empty_multipage.cpp emptyRenderer.cpp
emptymultipagepart_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN) -module
-emptymultipagepart_la_LIBADD = -lkparts libkmultipage.la
+emptymultipagepart_la_LIBADD = -ltdeparts libtdemultipage.la
libkviewshell_la_SOURCES = kviewshell.cpp
kviewshell_SOURCES = main.cpp
-kviewshell_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -lktexteditor
-kviewshell_LDADD = libkviewshell.la ./libifaces.la -lkparts
+kviewshell_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+kviewshell_LDADD = libkviewshell.la ./libifaces.la -ltdeparts
kviewshellinclude_HEADERS = anchor.h bookmark.h pageView.h documentPageCache.h documentRenderer.h documentWidget.h \
- history.h hyperlink.h kmultipage.h length.h pageNumber.h pageSize.h renderedDocumentPage.h renderedDocumentPagePixmap.h \
+ history.h hyperlink.h tdemultipage.h length.h pageNumber.h pageSize.h renderedDocumentPage.h renderedDocumentPagePixmap.h \
renderedDocumentPagePrinter.h selection.h simplePageSize.h textBox.h zoom.h zoomlimits.h
kviewshellincludedir = $(includedir)/kviewshell
@@ -55,7 +55,7 @@ rcdir = $(kde_datadir)/kviewshell
partrc_DATA = kviewerpart.rc
partrcdir = $(kde_datadir)/kviewerpart
-servicetype_DATA = kmultipage.desktop
+servicetype_DATA = tdemultipage.desktop
servicetypedir = $(kde_servicetypesdir)
kde_services_DATA = emptymultipage.desktop
diff --git a/kviewshell/TODO b/kviewshell/TODO
index b6139962..4e587fed 100644
--- a/kviewshell/TODO
+++ b/kviewshell/TODO
@@ -44,7 +44,7 @@ uses that to implement inverse and forward search functionality. We
must somehow make sure that even these unusual features fit well into
our framework without too much of an effort.
-* kmultipage
+* tdemultipage
- kviewshell should provide a print dialog (with the extra option that
certain document formats can insert their own configuration pages). I
@@ -70,7 +70,7 @@ applications that demonstrate how everything works. In particular, we
should have
* lots of documentation, including API documentation and a tutorial on
-"How to implement a kmultipage"
+"How to implement a tdemultipage"
* an exteremely well-defined reference implementation for a trivial
file format, either one that is actually useful (kfax, perhaps), or
@@ -87,7 +87,7 @@ KVIEWSHELL APPLICATION
* improve command line interface. The somewhat antique method of
giving the library name in the command line should be replaced by a
more modern method where kviewshell uses some kde wizardy
-(e.g. 'services') so that installed kmultipage implementations can
+(e.g. 'services') so that installed tdemultipage implementations can
announce what mime type they are supposed to handle, and kvieshell
then loads them automatically
diff --git a/kviewshell/empty_multipage.h b/kviewshell/empty_multipage.h
index b27fb1b6..5f425ec8 100644
--- a/kviewshell/empty_multipage.h
+++ b/kviewshell/empty_multipage.h
@@ -21,10 +21,10 @@
#ifndef EMPTY_MULTIPAGE_H
#define EMPTY_MULTIPAGE_H
-#include "kmultipage.h"
+#include "tdemultipage.h"
#include "emptyRenderer.h"
-#include <kparts/genericfactory.h>
+#include <tdeparts/genericfactory.h>
class EmptyMultiPage : public KMultiPage
diff --git a/kviewshell/kprintDialogPage_pageoptions.cpp b/kviewshell/kprintDialogPage_pageoptions.cpp
index c0c4b15e..1086b83f 100644
--- a/kviewshell/kprintDialogPage_pageoptions.cpp
+++ b/kviewshell/kprintDialogPage_pageoptions.cpp
@@ -102,7 +102,7 @@ void KPrintDialogPage_PageOptions::getOptions( TQMap<TQString,TQString>& opts, b
// Save options, taking default values into consideration: by
// default "center" is checked, "expand" and "shrink" are
// not. Warning: The default values are also coded into setOptions()
- // and kmultipage::print(..).
+ // and tdemultipage::print(..).
if (checkBox_center != 0)
if ( incldef || !checkBox_center->isChecked() )
@@ -138,7 +138,7 @@ void KPrintDialogPage_PageOptions::setOptions( const TQMap<TQString,TQString>& o
{
// Sets the centering option. By default, this option is
// checked. Warning: All default values are also coded into
- // getOptions() and kmultipage::print(..).
+ // getOptions() and tdemultipage::print(..).
TQString op = opts[ "kde-kviewshell-centerpage" ];
if (checkBox_center != 0)
checkBox_center->setChecked( op != "false" );
diff --git a/kviewshell/kviewpart.cpp b/kviewshell/kviewpart.cpp
index 847a8ff8..f76c5dd2 100644
--- a/kviewshell/kviewpart.cpp
+++ b/kviewshell/kviewpart.cpp
@@ -26,9 +26,9 @@
#include <kiconloader.h>
#include <kmessagebox.h>
#include <kmimetype.h>
-#include <kparts/componentfactory.h>
-#include <kparts/genericfactory.h>
-#include <kparts/partmanager.h>
+#include <tdeparts/componentfactory.h>
+#include <tdeparts/genericfactory.h>
+#include <tdeparts/partmanager.h>
#include <kprogress.h>
#include <kstandarddirs.h>
#include <kstdaction.h>
@@ -41,7 +41,7 @@
#include <math.h>
#include "kviewpart.h"
-#include "kmultipage.h"
+#include "tdemultipage.h"
#include "pageSize.h"
#include "pageSizeDialog.h"
#include "zoomlimits.h"
diff --git a/kviewshell/kviewpart.h b/kviewshell/kviewpart.h
index 1ea8aafd..cf66e69d 100644
--- a/kviewshell/kviewpart.h
+++ b/kviewshell/kviewpart.h
@@ -6,7 +6,7 @@
#include "pageSize.h"
#include "zoom.h"
-#include <kparts/browserextension.h>
+#include <tdeparts/browserextension.h>
#include <tqtimer.h>
class TDEAboutData;
@@ -71,7 +71,7 @@ public slots:
virtual TQStringList fileFormats() const;
void setStatusBarTextFromMultiPage(const TQString &);
- /** Calling this slot will cause the kmultipage to reload the file */
+ /** Calling this slot will cause the tdemultipage to reload the file */
void reload();
void restoreDocument(const KURL &url, int page);
diff --git a/kviewshell/kviewpart_iface.h b/kviewshell/kviewpart_iface.h
index bef0d233..009552f1 100644
--- a/kviewshell/kviewpart_iface.h
+++ b/kviewshell/kviewpart_iface.h
@@ -2,7 +2,7 @@
#ifndef KVIEWPART_IFACE_H
#define KVIEWPART_IFACE_H
-#include <kparts/part.h>
+#include <tdeparts/part.h>
class TQStringList;
diff --git a/kviewshell/kviewshell.cpp b/kviewshell/kviewshell.cpp
index 26f1e20b..b155e73e 100644
--- a/kviewshell/kviewshell.cpp
+++ b/kviewshell/kviewshell.cpp
@@ -25,7 +25,7 @@
#include <kstdaction.h>
#include <kedittoolbar.h>
#include <kurldrag.h>
-#include <kparts/partmanager.h>
+#include <tdeparts/partmanager.h>
#include <kmimetype.h>
#include <kprogress.h>
diff --git a/kviewshell/kviewshell.h b/kviewshell/kviewshell.h
index 064c4da1..40cf3244 100644
--- a/kviewshell/kviewshell.h
+++ b/kviewshell/kviewshell.h
@@ -4,7 +4,7 @@
#include <tqstring.h>
-#include <kparts/mainwindow.h>
+#include <tdeparts/mainwindow.h>
class KRecentFilesAction;
class KURL;
diff --git a/kviewshell/main.cpp b/kviewshell/main.cpp
index 132cbfda..a78f3620 100644
--- a/kviewshell/main.cpp
+++ b/kviewshell/main.cpp
@@ -114,7 +114,7 @@ int main(int argc, char **argv)
TQDataStream arg(data, IO_WriteOnly);
bool result;
arg << qualPath.stripWhiteSpace();
- if (!app.dcopClient()->call( *it, "kmultipage", "is_file_loaded(TQString)", data, replyType, replyData))
+ if (!app.dcopClient()->call( *it, "tdemultipage", "is_file_loaded(TQString)", data, replyType, replyData))
kdError(1223) << "There was an error using DCOP." << endl;
else
{
@@ -124,7 +124,7 @@ int main(int argc, char **argv)
reply >> result;
if (result == true)
{
- if (app.dcopClient()->send(*it, "kmultipage", "jumpToReference(TQString)", args->url(0).ref()) == true)
+ if (app.dcopClient()->send(*it, "tdemultipage", "jumpToReference(TQString)", args->url(0).ref()) == true)
{
app.dcopClient()->detach();
return 0;
diff --git a/kviewshell/plugins/djvu/CMakeLists.txt b/kviewshell/plugins/djvu/CMakeLists.txt
index 9a1bfce9..fe9d4ef9 100644
--- a/kviewshell/plugins/djvu/CMakeLists.txt
+++ b/kviewshell/plugins/djvu/CMakeLists.txt
@@ -42,6 +42,6 @@ tde_add_kpart( djvuviewpart AUTOMOC
kprintDialogPage_DJVUconversionoptions.cpp
kprintDialogPage_DJVUconversionoptions_basewidget.ui
pageRangeWidget_base.ui pageRangeWidget.cpp prefs.kcfgc
- LINK djvu-shared kmultipage-shared
+ LINK djvu-shared tdemultipage-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/kviewshell/plugins/djvu/Makefile.am b/kviewshell/plugins/djvu/Makefile.am
index 1dba2502..3f980a6d 100644
--- a/kviewshell/plugins/djvu/Makefile.am
+++ b/kviewshell/plugins/djvu/Makefile.am
@@ -18,7 +18,7 @@ shellrcdir = $(kde_datadir)/kviewshell/plugins/djvu
kde_module_LTLIBRARIES = djvuviewpart.la
djvuviewpart_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN) -module
-djvuviewpart_la_LIBADD = -ltdeprint -lkparts $(top_builddir)/kviewshell/libkmultipage.la libdjvu/libdjvu.la
+djvuviewpart_la_LIBADD = -ltdeprint -ltdeparts $(top_builddir)/kviewshell/libtdemultipage.la libdjvu/libdjvu.la
djvuviewpart_la_SOURCES = djvumultipage.cpp djvurenderer.cpp kprintDialogPage_DJVUpageoptions.cpp \
kprintDialogPage_DJVUconversionoptions.cpp kprintDialogPage_DJVUconversionoptions_basewidget.ui \
pageRangeWidget_base.ui pageRangeWidget.cpp \
diff --git a/kviewshell/plugins/djvu/djvumultipage.cpp b/kviewshell/plugins/djvu/djvumultipage.cpp
index 591447db..dd6d08b1 100644
--- a/kviewshell/plugins/djvu/djvumultipage.cpp
+++ b/kviewshell/plugins/djvu/djvumultipage.cpp
@@ -24,7 +24,7 @@
#include <kaction.h>
#include <kdialogbase.h>
#include <kfiledialog.h>
-#include <kparts/genericfactory.h>
+#include <tdeparts/genericfactory.h>
#include <kprinter.h>
#include <ktempfile.h>
#include "kvsprefs.h"
@@ -51,7 +51,7 @@ DjVuMultiPage::DjVuMultiPage(TQWidget *parentWidget, const char *widgetName, TQO
const char *name, const TQStringList&)
: KMultiPage(parentWidget, widgetName, parent, name), djvuRenderer(parentWidget)
{
- /* This is kparts wizardry that cannot be understood by man. Simply
+ /* This is tdeparts wizardry that cannot be understood by man. Simply
change the names to match your implementation. */
setInstance(DjVuMultiPageFactory::instance());
djvuRenderer.setName("DjVu renderer");
@@ -73,7 +73,7 @@ DjVuMultiPage::DjVuMultiPage(TQWidget *parentWidget, const char *widgetName, TQO
connect(renderModeAction, TQT_SIGNAL(activated(int)), this, TQT_SLOT(setRenderMode(int)));
/* It is very important that this method is called in the
- constructor. Otherwise kmultipage does not know how to render
+ constructor. Otherwise tdemultipage does not know how to render
files, and crashes may result. */
setRenderer(&djvuRenderer);
diff --git a/kviewshell/plugins/djvu/djvumultipage.h b/kviewshell/plugins/djvu/djvumultipage.h
index 163bf474..e6c47b14 100644
--- a/kviewshell/plugins/djvu/djvumultipage.h
+++ b/kviewshell/plugins/djvu/djvumultipage.h
@@ -26,7 +26,7 @@
#include <tqstringlist.h>
-#include "kmultipage.h"
+#include "tdemultipage.h"
#include "djvurenderer.h"
#include "DjVuToPS.h"
@@ -53,7 +53,7 @@ Only the two classes that are absolutely necessary for a working
plugin are implemented. The only other file that is installed is a
desktop file, which tells kviewhshell to use the plugin.
-- kvsdemo_multipage, an implementation of a kmultipage. In a real
+- kvsdemo_multipage, an implementation of a tdemultipage. In a real
application, this class would create and manage the GUI elements that
the plugin adds to the GUI of the kviewshell. This implementation adds
nothing, and does only the minimal initialization required..
@@ -93,7 +93,7 @@ public:
/** Constructor
The constructor needs to initialize several members of the
- kmultipage. Please have a look at the constructor's source code to
+ tdemultipage. Please have a look at the constructor's source code to
see how to adjust this for your implementation.
*/
DjVuMultiPage(TQWidget *parentWidget, const char *widgetName, TQObject *parent,
diff --git a/kviewshell/plugins/djvu/kprintDialogPage_DJVUpageoptions.cpp b/kviewshell/plugins/djvu/kprintDialogPage_DJVUpageoptions.cpp
index e6872648..cb932048 100644
--- a/kviewshell/plugins/djvu/kprintDialogPage_DJVUpageoptions.cpp
+++ b/kviewshell/plugins/djvu/kprintDialogPage_DJVUpageoptions.cpp
@@ -80,7 +80,7 @@ void KPrintDialogPage_DJVUPageOptions::getOptions( TQMap<TQString,TQString>& opt
{
// Save options, taking default values into consideration. Warning:
// The default values are also coded into setOptions() and
- // kmultipage::print(..).
+ // tdemultipage::print(..).
if (checkBox_rotate != 0)
if (checkBox_rotate->isChecked())
@@ -99,7 +99,7 @@ void KPrintDialogPage_DJVUPageOptions::getOptions( TQMap<TQString,TQString>& opt
void KPrintDialogPage_DJVUPageOptions::setOptions( const TQMap<TQString,TQString>& opts )
{
// Warning: All default values are also coded into getOptions() and
- // kmultipage::print(..).
+ // tdemultipage::print(..).
// same for rotation
TQString op = opts[ "kde-kviewshell-rotatepage" ];
diff --git a/kviewshell/kmultipage.desktop b/kviewshell/tdemultipage.desktop
index 0ef915a9..0ef915a9 100644
--- a/kviewshell/kmultipage.desktop
+++ b/kviewshell/tdemultipage.desktop
diff --git a/kviewshell/kmultipage.h b/kviewshell/tdemultipage.h
index 8dbd8247..ac3e6b02 100644
--- a/kviewshell/kmultipage.h
+++ b/kviewshell/tdemultipage.h
@@ -6,10 +6,10 @@
#include "documentPageCache.h"
#include "documentRenderer.h"
#include "history.h"
-#include "kmultipageInterface.h"
+#include "tdemultipageInterface.h"
#include "marklist.h"
-#include <kparts/part.h>
+#include <tdeparts/part.h>
#include <tqtimer.h>
class Anchor;
@@ -34,7 +34,7 @@ class SearchWidget;
*/
// TODO remove virtual inheritance for KDE 4. It's the reason for the strange DCOPObject construction
-class KMultiPage : public KParts::ReadOnlyPart, virtual public kmultipageInterface
+class KMultiPage : public KParts::ReadOnlyPart, virtual public tdemultipageInterface
{
Q_OBJECT
@@ -47,23 +47,23 @@ public:
virtual TQWidget* mainWidget() {return _scrollView;}
/* Methods which are associated with the DCOP functionality of the
- kmultipage. This method returns the file name (not the URL) of
+ tdemultipage. This method returns the file name (not the URL) of
the currently loaded file. */
TQString name_of_current_file();
/* Methods which are associated with the DCOP functionality of the
- kmultipage. This method can be implemented by the multipage,
+ tdemultipage. This method can be implemented by the multipage,
e.g. to jump to a certain location. */
virtual ASYNC jumpToReference(const TQString& /*reference*/);
/* Methods which are associated with the DCOP functionality of the
- kmultipage. This method checks if a given file is loaded. */
+ tdemultipage. This method checks if a given file is loaded. */
bool is_file_loaded(const TQString& filename);
/* Opens file and sets URL
This method does the same as openFile, but sets the m_url of the
- kmultipage. This can be important, for the following reason:
+ tdemultipage. This can be important, for the following reason:
assume that a DVI is or DJVU-file is located on a web server at
baseURL=http://www.x.x/x.dvi The file may refer to external
graphic files using relative links.
@@ -179,7 +179,7 @@ public:
@endcode
For more information, see the default implementation in the source
- file kmultipage.cpp. You might also look at the documentation to
+ file tdemultipage.cpp. You might also look at the documentation to
getPrinter().
*/
virtual void print();
@@ -319,7 +319,7 @@ protected:
/** Update GUI after loading or closing of a file
This method is called by openFile() when a new file was loaded,
- and by closeURL() when a file is closed so that the kmultipage
+ and by closeURL() when a file is closed so that the tdemultipage
implementation can update its own GUI, enable/disable actions,
prepare info texts, etc. At the time the method is executed, the
file has already been loaded into the renderer using
@@ -593,7 +593,7 @@ private slots:
private:
/* For internal use by the reload()-method. See the comments in
- kmultipage.cpp, right before the timerEvent function. */
+ tdemultipage.cpp, right before the timerEvent function. */
int timer_id;
/* For internal use the reload()-method. This is a dreadful
@@ -618,7 +618,7 @@ private:
void timerEvent( TQTimerEvent *e );
/* This method opens a file and sets up the GUI when the file is
- loaded. It calls setFile() so that implementations of kmultipage
+ loaded. It calls setFile() so that implementations of tdemultipage
can update their own GUI. DO NOT REIMPLEMENT THIS METHOD. */
bool openFile();
diff --git a/kviewshell/kmultipageInterface.h b/kviewshell/tdemultipageInterface.h
index 4c498900..e9dabf0f 100644
--- a/kviewshell/kmultipageInterface.h
+++ b/kviewshell/tdemultipageInterface.h
@@ -1,10 +1,10 @@
// -*- C++ -*-
-#ifndef kmultipageINTERFACE_H
-#define kmultipageINTERFACE_H
+#ifndef tdemultipageINTERFACE_H
+#define tdemultipageINTERFACE_H
#include <dcopobject.h>
-class kmultipageInterface : virtual public DCOPObject
+class tdemultipageInterface : virtual public DCOPObject
{
K_DCOP
diff --git a/kviewshell/kmultipage.cpp b/kviewshell/tdemultipage.cpp
index 4d544df9..b6b98855 100644
--- a/kviewshell/kmultipage.cpp
+++ b/kviewshell/tdemultipage.cpp
@@ -24,7 +24,7 @@
#include "tableOfContents.h"
#include "kprintDialogPage_pageoptions.h"
#include "kvsprefs.h"
-#include "kmultipage.h"
+#include "tdemultipage.h"
#include "pageNumber.h"
#include "renderedDocumentPagePrinter.h"
#include "searchWidget.h"
@@ -35,13 +35,13 @@
//#define DEBUG_KMULTIPAGE
KMultiPage::KMultiPage(TQWidget *parentWidget, const char *widgetName, TQObject *parent, const char *name)
- : DCOPObject("kmultipage"), KParts::ReadOnlyPart(parent, name)
+ : DCOPObject("tdemultipage"), KParts::ReadOnlyPart(parent, name)
{
// For reasons which I don't understand, the initialization of the
// DCOPObject above does not work properly, the name is ignored. It
// works fine if we repeat the name here. -- Stefan Kebekus
// This is because of the virtual inheritance. Get rid of it (but it's BC, and this is a lib...) -- DF
- setObjId("kmultipage");
+ setObjId("tdemultipage");
parentWdg = parentWidget;
lastCurrentPage = 0;
@@ -256,7 +256,7 @@ void KMultiPage::slotSetFullPage(bool fullpage)
void KMultiPage::preferencesChanged()
{
// We need to read the config options otherwise the KVSPrefs-object would
// not be syncronized between the kviewpart and the kmultipage.
KVSPrefs::self()->readConfig();
slotShowThumbnails(KVSPrefs::showThumbnails());
@@ -1837,7 +1837,7 @@ KPrinter *KMultiPage::getPrinter(bool enablePageSizeFeatures)
}
// Allocate a new KPrintDialogPage structure and add it to the
// printer, if the kmultipage implementation requests that
if (enablePageSizeFeatures == true) {
KPrintDialogPage_PageOptions *pageOptions = new KPrintDialogPage_PageOptions();
if (pageOptions == 0) {
@@ -1973,4 +1973,4 @@ void KMultiPage::slotEnableMoveTool(bool enable)
emit enableMoveTool(enable);
}
-#include "kmultipage.moc"
+#include "tdemultipage.moc"
@@ -256,7 +256,7 @@ void KMultiPage::slotSetFullPage(bool fullpage)
{
// We need to read the config options otherwise the KVSPrefs-object would
- // not be syncronized between the kviewpart and the kmultipage.
+ // not be syncronized between the kviewpart and the tdemultipage.
KVSPrefs::self()->readConfig();
slotShowThumbnails(KVSPrefs::showThumbnails());
@@ -1837,7 +1837,7 @@ KPrinter *KMultiPage::getPrinter(bool enablePageSizeFeatures)
}
// Allocate a new KPrintDialogPage structure and add it to the
- // printer, if the kmultipage implementation requests that
+ // printer, if the tdemultipage implementation requests that
if (enablePageSizeFeatures == true) {
KPrintDialogPage_PageOptions *pageOptions = new KPrintDialogPage_PageOptions();